@@ -7,7 +7,7 @@ with qw(
     eris::role::dictionary::hash
 );
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 
 sub _build_priority { 100 }
@@ -25,6 +25,10 @@ sub hash {
         timing => {
             type => 'object',
             description => 'Timing details for each step of the parsing',
+            properties => {
+                phase => { type => 'keyword' },
+                seconds => { type => 'float' },
+            }
         },
         total_time => {
             type => 'double',
@@ -48,7 +52,7 @@ eris::dictionary::eris::debug - Debugging data in the event
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
