@@ -7,7 +7,7 @@ with qw(
     eris::role::dictionary::hash
 );
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 
 sub _build_priority { 90; }
@@ -15,12 +15,13 @@ sub _build_priority { 90; }
 
 my $_hash=undef;
 sub hash {
+    my $self = shift;
     return $_hash if defined $_hash;
     my %data;
     while(<DATA>) {
         chomp;
-        my ($k,$desc) = split /\s+/, $_, 2;
-        $data{lc $k} = $desc;
+        my ($field,$def) = $self->expand_line($_);
+        $data{$field} = $def;
     }
     $_hash = \%data;
 }
@@ -38,7 +39,7 @@ eris::dictionary::syslog - Contains fields extracted from syslog messages
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -72,8 +73,8 @@ This is free software, licensed under:
 =cut
 
 __DATA__
-timestamp The timestamp encoded in the message
-message Message contents, often truncated to relevance.
+{ "name": "timestamp", "type": "date", "description": "The timestamp encoded in the message" }
+{ "name": "message", "type": "text", "description": "Message contents, often truncated to relevance" }
 severity Syslog severity of the message
 facility Syslog facility of the message
 program The program name or tag that generated the message
