@@ -2,10 +2,11 @@ package eris::role::dictionary::hash;
 # ABSTRACT: Simple dictionary implementation based off a hash
 
 use Moo::Role;
+use JSON::MaybeXS;
 use namespace::autoclean;
 with qw(eris::role::dictionary);
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 
 requires qw(hash);
@@ -19,6 +20,7 @@ sub lookup {
     if( exists $dict->{$field} ) {
         $entry = {
             field => $field,
+            type  => 'keyword',
             ref $dict->{$field} eq 'HASH' ? %{ $dict->{$field} }
                 : ( description => $dict->{$field} ),
         };
@@ -33,6 +35,30 @@ sub fields {
 }
 
 
+sub expand_line {
+    my ($self,$line) = @_;
+
+    my ($k,$v);
+    if( $line =~ /^{/ ) {
+        eval {
+            my $field = decode_json($line);
+            $k = lc delete $field->{name};
+            $v = $field;
+        } or do {
+            my $err = $@;
+            warn "BAD JSON: $err\n\n$line\n";
+        };
+    }
+    else {
+        my ($field,$desc) = split /\s+/, $line, 2;
+        $k = lc $field;
+        $v = $desc;
+    }
+
+    return $k ? ( $k => $v ) : ();
+}
+
+
 1;
 
 __END__
@@ -47,7 +73,7 @@ eris::role::dictionary::hash - Simple dictionary implementation based off a hash
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -91,6 +117,10 @@ Or if the hash value is a hash reference, we return:
 
 Returns the sorted list of keys in the lookup hash
 
+=head2 expand_line
+
+Expand a line in a file/DATA section to a workable hash
+
 =head1 INTERFACE
 
 =head2 hash
